Learn R Programming

sdcHierarchies (version 0.22.0)

hier_app: Create/Modify hierarchies interactively

Description

This function starts the interactive shiny-app to (optionally) create and/or modify a nested hierarchy. It is possible to supply a character vector from which the hierarchy can be interactively built. Once this has been done, it is possible to modify and export the resulting hierarchy.

Usage

hier_app(x = hier_create(), ...)

Value

The app can return a hierarchy object (either a data.frame or a tree-based object)

Arguments

x

a character vector containing nested levels or an object generated with hier_create()

...

arguments (e.g host) that are passed through shiny::runApp() when starting the shiny application

Details

Another option is to supply an already existing hierarchy object. In this case, it is possible to modify the existing object in the app.