Learn R Programming

sdcHierarchies (version 0.22.0)

hier_codes: Default-Codes

Description

hier_codes() returns the standardized codes for the nodes of a tree.

Usage

hier_codes(tree)

Value

a named character vector with names being the node-names and the values the standardized codes

Arguments

tree

a (nested) hierarchy created using hier_create() or modified using hier_add(), hier_delete() or hier_rename().

Examples

Run this code
h <- hier_create(root = "Total", nodes = LETTERS[1:3])
h <- hier_add(h, root = "A", nodes = c("a1", "a5"))
hier_codes(h)

Run the code above in your browser using DataLab