powered by
This function allows to extract the all the names of the nodes including all (sub)-nodes and leaves in the given hierarchy.
hier_nodenames(tree, root = NULL)
a (nested) hierarchy created using hier_create() or modified using hier_add(), hier_delete() or hier_rename().
hier_create()
hier_add()
hier_delete()
hier_rename()
(character) name of start node from which all lower level-names should be returned
h <- hier_create(root = "Total", nodes = LETTERS[1:3]) h <- hier_add(h, root = "A", nodes = c("a1", "a5")) hier_nodenames(h)
Run the code above in your browser using DataLab