powered by
hier_codes() returns the standardized codes for the nodes of a tree.
hier_codes()
hier_codes(tree)
a named character vector with names being the node-names and the values the standardized codes
a (nested) hierarchy created using hier_create() or modified using hier_add(), hier_delete() or hier_rename().
hier_create()
hier_add()
hier_delete()
hier_rename()
h <- hier_create(root = "Total", nodes = LETTERS[1:3]) h <- hier_add(h, root = "A", nodes = c("a1", "a5")) hier_codes(h)
Run the code above in your browser using DataLab