powered by
This functions allows to generate a hierarchical data structure that can be used in other packages such as cellKey or sdcTable.
cellKey
sdcTable
hier_create(root = "Total", nodes = NULL)
a (nested) sdc hierarchy tree
(character) name of the overall total
(character) name of leaves (nodes) in the hierarchy
hier_add hier_delete hier_rename hier_export hier_convert hier_app hier_info
# without nodes h <- hier_create(root = "tot") hier_display(h) # with nodes h <- hier_create(root = "tot", nodes = LETTERS[1:5]) hier_display(h)
Run the code above in your browser using DataLab